==> qtjambi-qt3danimation-debuginfo-windows-x64-5.15.18.jar: sources/QtJambi3DAnimation/QMorphTarget_shell.h <==
#ifndef QMORPHTARGET_SHELL_H
#define QMORPHTARGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DAnimation/qmorphtarget.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DRender/qattribute.h>
#include <Qt3DRender/qgeometry.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QMorphTarget_shell : public Qt3DAnimation::QMorphTarget, public QtJambiShellInterface
{
public:
    QMorphTarget_shell(QObject* parent0 = nullptr);
    ~QMorphTarget_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMorphTarget_access : public Qt3DAnimation::QMorphTarget
{
};

#endif // QMORPHTARGET_SHELL_H

==> qtjambi-qt3danimation-debuginfo-windows-x64-6.5.3.jar: sources/QtJambi3DAnimation/QMorphTarget_shell.h <==
#ifndef QMORPHTARGET_SHELL_H
#define QMORPHTARGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DAnimation/qmorphtarget.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qattribute.h>
#include <Qt3DCore/qgeometry.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QMorphTarget_shell : public Qt3DAnimation::QMorphTarget, public QtJambiShellInterface
{
public:
    QMorphTarget_shell(QObject* parent0 = nullptr);
    ~QMorphTarget_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMorphTarget_access : public Qt3DAnimation::QMorphTarget
{
};

#endif // QMORPHTARGET_SHELL_H
